@@ -1,6 +1,6 @@
 package Net::SMTP::TLS::ButMaintained;
 {
-    $Net::SMTP::TLS::ButMaintained::VERSION = '0.20';
+    $Net::SMTP::TLS::ButMaintained::VERSION = '0.22';
 }
 
 # ABSTRACT: An SMTP client supporting TLS and AUTH
@@ -110,7 +110,12 @@ sub starttls {
     if ( not $num == 220 ) {
         croak "Invalid response for STARTTLS: $num $txt\n";
     }
-    if ( not IO::Socket::SSL::socket_to_SSL( $me->{sock} ) ) {
+    if (
+        not IO::Socket::SSL::socket_to_SSL(
+            $me->{sock}, { SSL_verify_mode => IO::Socket::SSL::SSL_VERIFY_NONE }
+        )
+      )
+    {
         croak "Couldn't start TLS: " . IO::Socket::SSL::errstr . "\n";
     }
     $me->hello();
@@ -207,7 +212,7 @@ sub _addr {
 sub mail {
     my $me   = shift;
     my $from = shift;
-    $me->_command( "MAIL FROM: " . _addr($from) );
+    $me->_command( "MAIL FROM:" . _addr($from) );
     my ( $num, $txt ) = $me->_response();
     if ( not $num == 250 ) {
         croak "Could't set FROM: $num $txt\n";
@@ -220,7 +225,7 @@ sub recipient {
 
     my $addr;
     foreach $addr (@_) {
-        $me->_command( "RCPT TO: " . _addr($addr) );
+        $me->_command( "RCPT TO:" . _addr($addr) );
         my ( $num, $txt ) = $me->_response();
         if ( not $num == 250 ) {
             croak "Couldn't send TO <$addr>: $num $txt\n";
@@ -340,7 +345,7 @@ Net::SMTP::TLS::ButMaintained - An SMTP client supporting TLS and AUTH
 
 =head1 VERSION
 
-version 0.20
+version 0.22
 
 =head1 SYNOPSIS
 
